@@ -1,24 +1,22 @@
-r""" conftest.py - Parse, Query, Build, and Modify IOS-style configs
+r"""conftest.py - Parse, Query, Build, and Modify IOS-style configs
 
-     Copyright (C) 2020-2021 David Michael Pennington at Cisco Systems
-     Copyright (C) 2019      David Michael Pennington at ThousandEyes
-     Copyright (C) 2015-2019 David Michael Pennington at Samsung Data Services
+Copyright (C) 2023-2024  David Michael Pennington at Cisco Systems
 
-     This program is free software: you can redistribute it and/or modify
-     it under the terms of the GNU General Public License as published by
-     the Free Software Foundation, either version 3 of the License, or
-     (at your option) any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-     This program is distributed in the hope that it will be useful,
-     but WITHOUT ANY WARRANTY; without even the implied warranty of
-     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-     GNU General Public License for more details.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
-     You should have received a copy of the GNU General Public License
-     along with this program.  If not, see <http://www.gnu.org/licenses/>.
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-     If you need to contact the author, you can do so by emailing:
-     mike [~at~] pennington [/dot\] net
+If you need to contact the author, you can do so by emailing:
+mike [~at~] pennington [/dot\] net
 """
 
 import platform
@@ -27,8 +25,9 @@ import os
 
 sys.path.insert(0, "..")
 
-from ciscoconfparse.ciscoconfparse import CiscoConfParse
-from ciscoconfparse.ccp_util import PythonOptimizeCheck
+from ciscoconfparse2.ciscoconfparse2 import CiscoConfParse
+from ciscoconfparse2.ciscoconfparse2 import BraceParse
+from ciscoconfparse2.ccp_util import PythonOptimizeCheck
 import dns.exception
 import dns.resolver
 import pytest
@@ -579,6 +578,7 @@ ethernet-switching-options {
         interface all;
     }
 }
+}
 interfaces {
     ge-0/0/0 {
         unit 0 {
@@ -1290,7 +1290,6 @@ def parse_c02_factory(request):
     yield parse_c02
 
 
-## parse_c03 yields configs/sample_01.ios
 @pytest.fixture(scope="function")
 def parse_c03(request):
     """Preparsed c03"""
@@ -1299,7 +1298,6 @@ def parse_c03(request):
     yield parse_c03
 
 
-## parse_c03_factory yields configs/sample_01.ios
 @pytest.fixture(scope="function")
 def parse_c03_factory(request):
     """Preparsed c01 with factory option"""
@@ -1312,43 +1310,122 @@ def parse_c03_factory(request):
 @pytest.fixture(scope="function")
 def parse_f01_ios(request):
     """Preparsed F5 f01 configuration as ios syntax"""
-    parse_f01_ios = CiscoConfParse(f01, syntax="ios", comment="#", factory=False)
+    parse_f01_ios = CiscoConfParse(
+        f01, syntax="ios", comment_delimiters=["#"], factory=False
+    )
 
     yield parse_f01_ios
 
 
 ## parse_f02 yields configs/sample_02.f5
 @pytest.fixture(scope="function")
-def parse_f02_ios_01(request):
-    """Preparsed F5 f02 configuration as ios syntax"""
-    parse_f02_ios_01 = CiscoConfParse(f02, syntax="ios", comment="#", factory=False)
+def parse_f02_junos_01(request):
+    """Preparsed F5 f02 configuration as junos syntax"""
+    parse_f02_junos_01 = CiscoConfParse(
+        f02,
+        syntax="junos",
+        comment_delimiters=["#"],
+        ignore_blank_lines=True,
+        factory=False,
+    )
+
+    yield parse_f02_junos_01
 
-    yield parse_f02_ios_01
 
 @pytest.fixture(scope="function")
 def parse_f01_junos_01(request):
     """Preparsed F5 f01 configuration as junos syntax"""
-    parse_f01_junos_01 = CiscoConfParse(f01, syntax="junos", comment="#", factory=False)
+    parse_f01_junos_01 = CiscoConfParse(
+        f01, syntax="junos", comment_delimiters=["#"], factory=False
+    )
 
     yield parse_f01_junos_01
 
+
 ## parse_j01 yields configs/sample_01.junos
 @pytest.fixture(scope="function")
 def parse_j01(request):
     """Preparsed j01"""
-    parse_j01 = CiscoConfParse(j01, syntax="junos", comment="#!", factory=False)
+    parse_j01 = CiscoConfParse(
+        j01,
+        syntax="junos",
+        comment_delimiters=["#"],
+        ignore_blank_lines=True,
+        factory=False,
+    )
 
     yield parse_j01
 
+
 ## parse_j01_factory yields configs/sample_01.junos
 @pytest.fixture(scope="function")
 def parse_j01_factory(request):
     """Preparsed j01 with factory option"""
-    parse_j01_factory = CiscoConfParse(j01, syntax="junos", comment="#!", factory=True)
+    parse_j01_factory = CiscoConfParse(
+        j01, syntax="junos", comment_delimiters=["#", "!"], factory=True
+    )
 
     yield parse_j01_factory
 
 
+## parse_j01 yields configs/sample_01.junos
+@pytest.fixture(scope="function")
+def parse_j01(request):
+    """Preparsed j01"""
+    parse_j01 = CiscoConfParse(
+        j01,
+        syntax="junos",
+        comment_delimiters=["#"],
+        ignore_blank_lines=True,
+        factory=False,
+    )
+
+    yield parse_j01
+
+
+## parse_fixture_j01 yields fixtures/configs/sample_01.junos
+@pytest.fixture(scope="function")
+def parse_fixture_j01(request):
+    """Preparsed j01"""
+    parse_fixture_j01 = CiscoConfParse(
+        "fixtures/configs/sample_01.junos",
+        syntax="junos",
+        comment_delimiters=["#"],
+        ignore_blank_lines=True,
+        factory=False,
+    )
+
+    yield parse_fixture_j01
+
+
+## parse_fixture_j03 yields fixtures/configs/sample_03.junos
+@pytest.fixture(scope="function")
+def parse_fixture_j03(request):
+    """Preparsed j03"""
+    parse_fixture_j03 = CiscoConfParse(
+        "fixtures/configs/sample_03.junos",
+        syntax="junos",
+        comment_delimiters=["#"],
+        ignore_blank_lines=True,
+        factory=False,
+    )
+
+    yield parse_fixture_j03
+
+
+## parse_fixture_j03 yields fixtures/configs/sample_03.junos
+@pytest.fixture(scope="function")
+def brace_fixture_j03(request):
+    """Preparsed j03"""
+    brace_fixture_j03 = BraceParse(
+        "fixtures/configs/sample_03.junos",
+        comment_delimiters=["#"],
+        ignore_blank_lines=True,
+    )
+
+    yield brace_fixture_j03
+
+
 ## parse_a01 yields the asa configuration
 @pytest.fixture(scope="function")
 def parse_a01(request):
@@ -1398,14 +1475,18 @@ def config_n01(request):
     """Unparsed n01"""
     yield n01
 
+
 ## parse_n01 yields a nexus configuration
 @pytest.fixture(scope="function")
 def parse_n01_w_blanklines(request):
     """Preparsed n01 with no ignored blank lines"""
-    parse_n01_blanklines = CiscoConfParse(n01, syntax="nxos", ignore_blank_lines=False, factory=False)
+    parse_n01_blanklines = CiscoConfParse(
+        n01, syntax="nxos", ignore_blank_lines=False, factory=False
+    )
 
     yield parse_n01_blanklines
 
+
 ## parse_n01 yields a nexus configuration
 @pytest.fixture(scope="function")
 def parse_n01(request):
@@ -1424,20 +1505,73 @@ def parse_n01_factory(request):
     yield parse_n01_factory
 
 
-@pytest.mark.skipif(sys.version_info[0] >= 3, reason="No Python3 MockSSH support")
-@pytest.mark.skipif(
-    "windows" in platform.system().lower(), reason="No Windows MockSSH support"
-)
-@pytest.fixture(scope="session")
-def cisco_sshd_mocked(request):
-    """Mock Cisco IOS SSH"""
-    from fixtures.devices.mock_cisco import start_cisco_mock, stop_cisco_mock
+@pytest.fixture(scope="function")
+def parse_sample_01_ios_factory(request):
+    """Preparsed sample_01.ios with factory option"""
+    parse = CiscoConfParse("fixtures/configs/sample_01.ios", syntax="ios", factory=True)
 
-    try:
-        ## Start the SSH Server
-        start_cisco_mock()
-        yield True
-    except:
-        yield False
-        stop_cisco_mock()
-    stop_cisco_mock()
+    yield parse
+
+
+@pytest.fixture(scope="function")
+def parse_sample_02_ios_factory(request):
+    """Preparsed sample_02.ios with factory option"""
+    parse = CiscoConfParse("fixtures/configs/sample_02.ios", syntax="ios", factory=True)
+
+    yield parse
+
+
+@pytest.fixture(scope="function")
+def parse_sample_03_ios_factory(request):
+    """Preparsed sample_03.ios with factory option"""
+    parse = CiscoConfParse("fixtures/configs/sample_03.ios", syntax="ios", factory=True)
+
+    yield parse
+
+
+@pytest.fixture(scope="function")
+def parse_sample_04_ios_factory(request):
+    """Preparsed sample_04.ios with factory option"""
+    parse = CiscoConfParse("fixtures/configs/sample_04.ios", syntax="ios", factory=True)
+
+    yield parse
+
+
+@pytest.fixture(scope="function")
+def parse_sample_05_ios_factory(request):
+    """Preparsed sample_05.ios with factory option"""
+    parse = CiscoConfParse("fixtures/configs/sample_05.ios", syntax="ios", factory=True)
+
+    yield parse
+
+
+@pytest.fixture(scope="function")
+def parse_sample_06_ios_factory(request):
+    """Preparsed sample_06.ios with factory option"""
+    parse = CiscoConfParse("fixtures/configs/sample_06.ios", syntax="ios", factory=True)
+
+    yield parse
+
+
+@pytest.fixture(scope="function")
+def parse_sample_07_ios_factory(request):
+    """Preparsed sample_07.ios with factory option"""
+    parse = CiscoConfParse("fixtures/configs/sample_07.ios", syntax="ios", factory=True)
+
+    yield parse
+
+
+@pytest.fixture(scope="function")
+def parse_sample_08_ios_factory(request):
+    """Preparsed sample_08.ios with factory option"""
+    parse = CiscoConfParse("fixtures/configs/sample_08.ios", syntax="ios", factory=True)
+
+    yield parse
+
+
+@pytest.fixture(scope="function")
+def parse_sample_09_ios_factory(request):
+    """Preparsed sample_09.ios with factory option"""
+    parse = CiscoConfParse("fixtures/configs/sample_09.ios", syntax="ios", factory=True)
+
+    yield parse
